@@ -7,10 +7,13 @@ import os
 
 
 def RegisterCommands(dir="./GooblerPKG/basic/commands/"):
-  if not os.listdir(dir):
+  try:
+    if os.listdir(dir): pass
+  except:
     os.mkdir(dir)
     with open(f'{dir}/Information', 'w') as f:
       f.write('For each command you need to add, make a new .py file inside the parent directory.')
+
   for each in os.listdir(dir):
     if each.endswith('.py'):
       print("\n Registered command "+str(each))
\ No newline at end of file
