@@ -6,7 +6,7 @@ import time
 import random
 import json
 import requests
-#from .config import colors
+from .gooblerpkg.config import colors
 
 ###################
 ### Goobler 2022 ##
@@ -15,16 +15,16 @@ import requests
 
 # PURE CLASSES:
 
-class colors:
-  HEADER = '\033[95m'
-  OKBLUE = '\033[94m'
-  OKCYAN = '\033[96m'
-  OKGREEN = '\033[92m'
-  WARNING = '\033[93m'
-  FAIL = '\033[91m'
-  ENDC = '\033[0m'
-  BOLD = '\033[1m'
-  UNDERLINE = '\033[4m'
+#class colors:
+  #HEADER = '\033[95m'
+  #OKBLUE = '\033[94m'
+  #OKCYAN = '\033[96m'
+  #OKGREEN = '\033[92m'
+  #WARNING = '\033[93m'
+  #FAIL = '\033[91m'
+  #ENDC = '\033[0m'
+  #BOLD = '\033[1m'
+  #UNDERLINE = '\033[4m'
 
 # PURE FUNCS:
 
